# how.

> How do I ...?
>
> This project was started to help developers ask more questions.

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Foss](#foss)
- [Community](#community)
- [Copyright](#copyright)



## Installation

Install as you would with pip **using pypi** under the name `askquestions` - 

    $ pip3 install askquestions
    
Or **git** - 

    $ pip3 install git+https://github.com/ronnathaniel/how
    
Or **from source** -

    $ git clone https://github.com/ronnathaniel/how.git
    $ cd how
    $ pip3 install .

## Usage

    $ how QUERY ... [-n N]

Ask your terminal directly.

    $ how do i exit vim
    ➜       https://stackoverflow.com/questions/11828270/how-do-i-exit-the-vim-editor
    ➜       https://stackoverflow.com/questions/25919461/i-cannot-exit-vim-i-hit-escape-and-tried-q-x-qx
    ➜       https://stackoverflow.com/questions/47315349/how-to-exit-the-vim-editor-when-q-or-x-doesnt-work
    ➜       https://stackoverflow.com/questions/1879219/how-to-temporarily-exit-vim-and-go-back
    ➜       https://stackoverflow.com/questions/31140908/how-do-i-save-and-quit-from-vim

Arguments

- `-n`: (int) Amount of links to return. Defaults to 5.

## FOSS 

[`googlesearch-python`](https://pypi.org/project/googlesearch-python/) - A Python library for scraping the Google search engine.



## Community

We want to build a community of question-askers.

After all, it is only when we ask questions that we can learn anything.

Contributions are more than welcome, maintainers are always invited, and if you can ask questions you're a VIP.

## Copyright

MIT License. 

All rights reserved.

![a-dead-poets-society](https://cdn.quotesgram.com/img/59/18/595506754-m_1918662_hxtIlAK3iZaf.jpg)

end.